const { test, expect } = require("@jest/globals");
const { spawn } = require("child_process");

test("Insufficient params", () => {
    const main = spawn("node", ["main.js", "avg"]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("Insufficient parameter!");
    });
});

test("Wrong command", () => {
    const main = spawn("node", ["main.js", "count", "0"]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("Wrong command!");
    });
});

test("Invalid repeat", () => {
    const main = spawn("node", ["main.js", "min", "3@0", "4"]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("Invalid repeat!");
    });
});

test("'stat min 2@2 -1@4 3@1 5' should be -1", () => {
    const main = spawn("node", ["main.js", "min", "2@2", "-1@4", "3@1", "5"]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("-1");
    });
});

test("'stat med 2@2 3 100 2@2 -1 4@3' should be 2.5", () => {
    const main = spawn("node", [
        "main.js",
        "med",
        "2@2",
        "3",
        "100",
        "2@2",
        "-1",
        "4@3",
    ]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("2.5");
    });
});

test("3@1a is Invalid repeat!", () => {
    const main = spawn("node", [
        "main.js",
        "med",
        "6@2",
        "3@1a",
        "23",
        "2",
        "-53",
        "4@1",
    ]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("Invalid repeat!");
    });
});

test("1.1a should print 'Some arguments are not numbers!'", () => {
    const main = spawn("node", ["main.js", "med", "1.1a", "2.2b", "3.3c"]);
    const outputs = [];
    main.stdout.on("data", (output) => {
        outputs.push(output);
    });
    main.stdout.on("end", () => {
        const output = outputs.join("").trim();
        expect(output).toBe("Some arguments are not numbers!");
    });
});
